==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/libs/base/src/utils/mrpt_font_10x20.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_10x20 [] = {
31,139,8,0,0,0,0,0,4,3,237,155,191,139,36,199,
21,199,71,63,216,64,12,70,24,7,3,62,132,112,100,20,
93,116,76,176,28,14,141,3,255,13,141,49,27,136,197,92,
36,22,179,136,197,8,69,194,56,50,27,24,57,49,138,141,
3,99,176,17,29,13,14,150,67,225,98,20,92,180,145,17,
139,131,99,130,229,228,239,231,174,191,203,115,93,117,85,205,
244,24,99,232,7,223,123,175,94,189,250,214,171,87,213,61,
221,179,115,239,44,22,139,239,9,200,183,175,212,253,191,79,
223,88,44,222,28,96,167,219,104,139,125,196,207,50,87,96,
174,192,92,129,185,2,115,5,230,10,204,21,152,43,48,87,
192,21,120,40,163,5,196,59,206,99,115,250,74,78,227,199,
185,128,61,124,127,212,51,172,113,247,214,98,113,45,14,227,
133,250,78,213,54,106,244,172,225,78,248,179,198,61,146,54,
240,121,14,52,253,248,136,175,201,239,134,248,231,10,252,90,
232,6,184,94,215,234,63,83,222,167,194,149,236,146,172,213,
233,181,160,143,133,149,240,64,32,215,19,113,108,196,177,145,
253,141,244,177,218,37,113,14,214,239,150,130,27,250,122,197,
116,130,249,200,45,133,251,136,235,133,146,44,213,201,248,56,
166,83,59,194,125,196,17,223,42,87,10,4,103,2,231,4,
109,159,204,157,197,121,160,225,139,237,157,201,26,6,60,81,
12,88,55,196,166,33,228,247,223,20,231,134,174,201,133,114,
1,189,2,65,55,224,161,52,96,95,1,123,11,74,66,124,
220,199,79,197,155,194,123,76,28,241,37,161,127,45,112,157,
113,125,209,46,161,86,87,231,230,156,226,218,159,136,123,37,
176,198,163,1,251,240,245,26,11,23,26,126,207,197,186,153,
191,36,23,234,236,133,103,194,173,112,45,48,110,51,128,124,
122,217,17,106,142,10,241,71,234,141,248,72,237,167,130,215,
238,28,91,242,187,175,95,224,52,159,215,105,221,194,71,126,
206,163,23,39,232,6,120,159,217,19,176,28,32,53,42,247,
249,101,234,78,62,206,13,221,146,95,142,239,229,88,141,255,
75,200,253,147,70,190,92,226,156,21,144,202,152,63,141,75,
219,99,227,236,95,167,3,66,251,66,118,47,116,194,67,193,
117,231,252,80,127,218,248,59,161,23,46,132,93,36,119,61,
229,124,99,156,111,171,35,155,135,234,223,171,175,19,98,222,
196,151,36,183,191,189,6,116,2,60,134,204,255,176,105,231,
36,242,221,40,167,231,2,207,42,198,115,13,58,17,168,231,
103,242,111,115,36,193,199,252,230,76,207,47,117,139,231,217,
118,24,254,154,249,88,30,230,223,4,208,254,120,104,155,3,
77,12,254,146,56,55,226,143,20,56,6,250,91,174,183,92,
30,49,167,104,183,228,71,141,114,57,49,79,206,95,59,139,
187,242,49,71,73,198,234,119,163,188,227,90,177,121,54,61,
19,74,146,142,113,123,236,172,208,95,18,198,249,26,104,209,
181,250,221,190,181,88,244,154,176,132,141,250,193,169,176,22,
74,226,245,121,204,137,130,193,227,65,99,187,207,177,114,141,
202,145,122,118,65,109,189,158,147,239,249,1,241,190,23,88,
59,198,122,52,57,117,16,243,235,1,159,75,3,243,220,200,
6,155,1,196,130,146,196,243,231,248,49,61,229,250,101,15,
198,174,185,169,249,177,254,27,129,252,182,2,207,19,99,50,
118,127,113,126,39,26,136,13,92,135,49,46,252,177,126,71,
106,131,229,224,239,165,253,108,3,87,75,253,56,31,45,215,
89,140,209,52,163,226,53,180,232,150,252,82,30,198,24,212,
194,152,146,159,207,179,181,175,29,207,61,186,88,117,56,38,
205,137,124,156,155,251,28,187,47,95,92,99,180,75,124,236,
175,207,68,175,192,110,0,227,87,3,150,210,62,75,196,151,
228,78,157,196,183,130,248,154,152,203,249,120,109,157,6,130,
126,128,215,161,230,168,48,95,191,3,106,249,145,11,251,120,
37,176,127,255,11,121,161,207,176,49,161,102,228,216,141,5,
28,192,191,21,7,207,142,212,255,78,240,57,70,159,11,37,
241,185,138,122,236,253,141,119,68,250,118,21,231,23,231,192,
110,121,222,245,153,138,154,247,44,158,125,226,58,177,241,209,
183,171,196,243,195,245,229,60,91,242,187,213,100,151,26,3,
216,107,192,103,138,237,156,86,247,78,194,30,110,128,70,25,
231,178,201,147,235,35,214,33,189,94,188,150,168,199,246,215,
60,162,172,138,239,1,4,30,11,110,167,186,118,191,242,68,
222,95,218,207,180,86,183,115,154,125,49,182,38,24,116,92,
167,237,141,250,78,132,71,194,123,194,227,161,141,159,53,151,
164,180,182,116,173,180,91,215,27,231,252,199,48,206,159,111,
169,142,177,45,246,33,246,55,206,115,166,134,239,175,62,35,
104,124,244,237,42,99,249,249,254,226,125,179,174,241,215,238,
7,233,25,170,241,61,87,0,127,35,240,231,94,170,107,227,
211,126,95,163,172,7,219,249,80,67,218,45,18,239,35,99,
247,23,238,65,183,45,100,73,76,220,211,104,239,123,63,53,
7,231,195,103,132,115,226,235,37,153,190,218,52,31,58,94,
27,92,107,240,239,42,240,56,47,231,20,207,248,62,124,49,
71,219,174,31,251,29,231,172,241,243,25,206,152,94,129,157,
64,142,236,255,82,160,175,36,207,212,239,53,69,205,125,47,
182,109,19,95,18,199,237,162,75,124,165,60,114,115,16,95,
18,174,83,206,196,77,41,104,238,155,43,48,87,96,174,192,
92,129,185,2,115,5,230,10,204,21,152,43,240,127,90,1,
63,35,147,190,237,154,174,45,213,227,239,223,129,52,192,239,
222,159,202,78,223,149,106,124,183,10,168,125,39,246,88,49,
31,234,123,83,190,203,111,149,55,20,251,87,225,133,6,108,
2,104,227,167,191,85,248,255,54,241,157,140,247,112,234,96,
237,154,160,75,18,227,108,199,120,251,162,142,253,169,237,61,
96,125,188,239,29,11,39,2,123,224,247,251,94,54,223,127,
121,95,212,28,21,98,192,161,197,121,82,195,95,10,63,17,
222,25,52,237,88,219,210,220,91,117,242,91,25,222,119,121,
183,101,28,56,23,144,125,190,79,99,220,251,26,207,239,66,
175,101,159,10,124,247,247,253,65,211,198,79,63,113,187,10,
57,129,139,1,187,142,207,197,183,126,15,148,27,139,47,183,
31,236,195,7,194,135,66,203,126,236,91,235,177,156,240,115,
238,157,27,231,16,27,223,161,196,215,21,185,219,134,187,117,
45,107,197,114,30,58,129,241,43,97,41,156,11,251,72,202,
215,137,4,126,252,251,72,167,65,206,107,159,241,173,99,226,
253,212,246,55,26,252,165,112,20,144,242,113,205,82,235,47,
3,254,38,59,254,54,59,181,83,142,90,251,137,2,140,90,
236,33,250,169,119,39,228,246,141,243,241,64,64,71,112,159,
222,71,56,23,204,227,154,163,227,188,124,182,237,35,223,213,
32,238,121,112,93,11,236,65,167,207,91,52,109,252,244,19,
87,18,126,47,199,254,191,173,113,159,72,255,84,120,95,248,
141,240,119,225,15,194,191,132,139,1,82,69,25,227,251,74,
163,126,168,57,152,231,87,178,127,36,60,147,93,147,239,40,
224,93,97,169,88,114,202,230,167,190,11,245,129,154,60,84,
0,64,108,163,217,235,165,224,207,167,218,253,148,88,198,68,
174,51,181,175,18,14,174,157,200,137,157,147,94,206,78,56,
20,31,60,206,71,230,75,94,183,99,62,173,249,93,138,131,
207,176,159,67,38,137,252,251,240,81,39,128,68,174,125,234,
231,117,49,22,27,137,156,251,228,247,138,69,127,111,209,126,
193,121,58,224,68,26,80,55,219,81,223,140,236,175,134,188,
20,231,74,78,71,242,140,129,126,175,135,181,116,2,57,172,
5,100,41,172,4,250,16,242,73,185,62,150,63,245,17,151,
147,78,78,184,224,68,166,242,197,250,31,130,143,90,0,203,
212,252,92,187,110,32,228,108,147,115,13,196,229,164,147,51,
214,111,42,95,90,191,169,124,177,126,173,92,228,48,182,94,
215,128,51,182,17,226,53,134,253,123,33,245,17,71,124,78,
46,229,100,46,223,95,24,203,239,30,63,31,224,191,11,222,
168,13,54,2,49,32,39,233,254,158,41,136,26,120,76,78,
211,79,92,78,58,57,227,254,78,229,75,247,119,42,223,165,
242,139,245,155,202,23,207,75,11,23,245,44,213,47,87,83,
251,120,30,224,108,156,10,235,1,216,248,232,27,21,205,185,
85,39,243,110,100,131,47,2,126,43,219,224,44,17,119,46,
188,41,164,178,146,131,61,233,134,14,214,83,3,124,212,38,
39,157,156,241,188,212,184,232,47,241,165,231,101,42,31,115,
1,164,133,171,150,95,39,158,220,122,61,15,117,2,196,164,
144,107,84,150,234,49,56,223,124,47,146,2,191,99,208,37,
121,162,206,107,193,28,87,178,127,33,156,10,216,246,163,105,
227,175,201,74,1,172,169,27,2,201,135,122,241,253,65,252,
206,3,159,191,247,24,66,179,170,147,23,62,120,145,169,124,
112,81,123,214,131,76,229,187,28,56,124,175,158,202,71,78,
228,118,136,252,188,78,184,176,145,67,228,247,138,233,213,191,
95,75,253,73,123,201,187,214,173,236,99,129,119,173,71,106,
255,83,122,87,217,106,0,231,237,72,58,2,31,125,62,91,
167,178,215,66,42,75,57,86,2,113,200,153,192,250,57,111,
241,57,201,124,196,148,164,87,103,39,28,138,15,30,231,36,
243,222,222,55,63,56,88,31,64,204,189,47,95,90,63,246,
147,156,115,160,158,53,233,20,192,88,246,4,153,202,151,214,
111,42,31,57,197,250,77,225,251,129,184,56,251,15,6,96,
255,76,216,10,87,170,21,123,98,48,39,123,85,147,75,5,
220,9,190,191,124,36,251,169,96,158,84,171,171,40,233,254,
146,3,185,164,60,173,249,245,26,219,9,236,11,50,149,47,
221,223,169,124,105,253,166,242,177,70,106,3,144,67,240,177,
102,215,15,78,174,171,120,109,165,253,196,52,137,120,182,10,
36,215,47,100,3,63,3,226,59,23,114,207,127,114,223,203,
74,22,243,119,131,39,61,39,110,115,190,249,109,106,77,122,
5,116,130,215,235,241,169,110,229,131,199,123,32,243,181,115,
108,222,86,62,56,226,254,122,124,170,91,249,58,241,145,35,
117,68,82,30,183,205,199,115,18,62,114,96,93,81,150,106,
228,192,62,18,255,153,198,25,180,241,167,241,114,189,38,196,
2,196,249,164,186,150,223,191,1,100,123,132,121,24,80,0,
0,};

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/libs/base/src/utils/mrpt_font_10x20.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

static const unsigned char mrpt_font_gz_10x20 [] = {
31,139,8,0,0,0,0,0,4,3,237,155,191,139,36,199,
21,199,71,63,216,64,12,70,24,7,3,62,132,112,100,20,
93,116,76,176,28,14,141,3,255,13,141,49,27,136,197,92,
36,22,179,136,197,8,69,194,56,50,27,24,57,49,138,141,
3,99,176,17,29,13,14,150,67,225,98,20,92,180,145,17,
139,131,99,130,229,228,239,231,174,191,203,115,93,117,85,205,
244,24,99,232,7,223,123,175,94,189,250,214,171,87,213,61,
221,179,115,239,44,22,139,239,9,200,183,175,212,253,191,79,
223,88,44,222,28,96,167,219,104,139,125,196,207,50,87,96,
174,192,92,129,185,2,115,5,230,10,204,21,152,43,48,87,
192,21,120,40,163,5,196,59,206,99,115,250,74,78,227,199,
185,128,61,124,127,212,51,172,113,247,214,98,113,45,14,227,
133,250,78,213,54,106,244,172,225,78,248,179,198,61,146,54,
240,121,14,52,253,248,136,175,201,239,134,248,231,10,252,90,
232,6,184,94,215,234,63,83,222,167,194,149,236,146,172,213,
233,181,160,143,133,149,240,64,32,215,19,113,108,196,177,145,
253,141,244,177,218,37,113,14,214,239,150,130,27,250,122,197,
116,130,249,200,45,133,251,136,235,133,146,44,213,201,248,56,
166,83,59,194,125,196,17,223,42,87,10,4,103,2,231,4,
109,159,204,157,197,121,160,225,139,237,157,201,26,6,60,81,
12,88,55,196,166,33,228,247,223,20,231,134,174,201,133,114,
1,189,2,65,55,224,161,52,96,95,1,123,11,74,66,124,
220,199,79,197,155,194,123,76,28,241,37,161,127,45,112,157,
113,125,209,46,161,86,87,231,230,156,226,218,159,136,123,37,
176,198,163,1,251,240,245,26,11,23,26,126,207,197,186,153,
191,36,23,234,236,133,103,194,173,112,45,48,110,51,128,124,
122,217,17,106,142,10,241,71,234,141,248,72,237,167,130,215,
238,28,91,242,187,175,95,224,52,159,215,105,221,194,71,126,
206,163,23,39,232,6,120,159,217,19,176,28,32,53,42,247,
249,101,234,78,62,206,13,221,146,95,142,239,229,88,141,255,
75,200,253,147,70,190,92,226,156,21,144,202,152,63,141,75,
219,99,227,236,95,167,3,66,251,66,118,47,116,194,67,193,
117,231,252,80,127,218,248,59,161,23,46,132,93,36,119,61,
229,124,99,156,111,171,35,155,135,234,223,171,175,19,98,222,
196,151,36,183,191,189,6,116,2,60,134,204,255,176,105,231,
36,242,221,40,167,231,2,207,42,198,115,13,58,17,168,231,
103,242,111,115,36,193,199,252,230,76,207,47,117,139,231,217,
118,24,254,154,249,88,30,230,223,4,208,254,120,104,155,3,
77,12,254,146,56,55,226,143,20,56,6,250,91,174,183,92,
30,49,167,104,183,228,71,141,114,57,49,79,206,95,59,139,
187,242,49,71,73,198,234,119,163,188,227,90,177,121,54,61,
19,74,146,142,113,123,236,172,208,95,18,198,249,26,104,209,
181,250,221,190,181,88,244,154,176,132,141,250,193,169,176,22,
74,226,245,121,204,137,130,193,227,65,99,187,207,177,114,141,
202,145,122,118,65,109,189,158,147,239,249,1,241,190,23,88,
59,198,122,52,57,117,16,243,235,1,159,75,3,243,220,200,
6,155,1,196,130,146,196,243,231,248,49,61,229,250,101,15,
198,174,185,169,249,177,254,27,129,252,182,2,207,19,99,50,
118,127,113,126,39,26,136,13,92,135,49,46,252,177,126,71,
106,131,229,224,239,165,253,108,3,87,75,253,56,31,45,215,
89,140,209,52,163,226,53,180,232,150,252,82,30,198,24,212,
194,152,146,159,207,179,181,175,29,207,61,186,88,117,56,38,
205,137,124,156,155,251,28,187,47,95,92,99,180,75,124,236,
175,207,68,175,192,110,0,227,87,3,150,210,62,75,196,151,
228,78,157,196,183,130,248,154,152,203,249,120,109,157,6,130,
126,128,215,161,230,168,48,95,191,3,106,249,145,11,251,120,
37,176,127,255,11,121,161,207,176,49,161,102,228,216,141,5,
28,192,191,21,7,207,142,212,255,78,240,57,70,159,11,37,
241,185,138,122,236,253,141,119,68,250,118,21,231,23,231,192,
110,121,222,245,153,138,154,247,44,158,125,226,58,177,241,209,
183,171,196,243,195,245,229,60,91,242,187,213,100,151,26,3,
216,107,192,103,138,237,156,86,247,78,194,30,110,128,70,25,
231,178,201,147,235,35,214,33,189,94,188,150,168,199,246,215,
60,162,172,138,239,1,4,30,11,110,167,186,118,191,242,68,
222,95,218,207,180,86,183,115,154,125,49,182,38,24,116,92,
167,237,141,250,78,132,71,194,123,194,227,161,141,159,53,151,
164,180,182,116,173,180,91,215,27,231,252,199,48,206,159,111,
169,142,177,45,246,33,246,55,206,115,166,134,239,175,62,35,
104,124,244,237,42,99,249,249,254,226,125,179,174,241,215,238,
7,233,25,170,241,61,87,0,127,35,240,231,94,170,107,227,
211,126,95,163,172,7,219,249,80,67,218,45,18,239,35,99,
247,23,238,65,183,45,100,73,76,220,211,104,239,123,63,53,
7,231,195,103,132,115,226,235,37,153,190,218,52,31,58,94,
27,92,107,240,239,42,240,56,47,231,20,207,248,62,124,49,
71,219,174,31,251,29,231,172,241,243,25,206,152,94,129,157,
64,142,236,255,82,160,175,36,207,212,239,53,69,205,125,47,
182,109,19,95,18,199,237,162,75,124,165,60,114,115,16,95,
18,174,83,206,196,77,41,104,238,155,43,48,87,96,174,192,
92,129,185,2,115,5,230,10,204,21,152,43,240,127,90,1,
63,35,147,190,237,154,174,45,213,227,239,223,129,52,192,239,
222,159,202,78,223,149,106,124,183,10,168,125,39,246,88,49,
31,234,123,83,190,203,111,149,55,20,251,87,225,133,6,108,
2,104,227,167,191,85,248,255,54,241,157,140,247,112,234,96,
237,154,160,75,18,227,108,199,120,251,162,142,253,169,237,61,
96,125,188,239,29,11,39,2,123,224,247,251,94,54,223,127,
121,95,212,28,21,98,192,161,197,121,82,195,95,10,63,17,
222,25,52,237,88,219,210,220,91,117,242,91,25,222,119,121,
183,101,28,56,23,144,125,190,79,99,220,251,26,207,239,66,
175,101,159,10,124,247,247,253,65,211,198,79,63,113,187,10,
57,129,139,1,187,142,207,197,183,126,15,148,27,139,47,183,
31,236,195,7,194,135,66,203,126,236,91,235,177,156,240,115,
238,157,27,231,16,27,223,161,196,215,21,185,219,134,187,117,
45,107,197,114,30,58,129,241,43,97,41,156,11,251,72,202,
215,137,4,126,252,251,72,167,65,206,107,159,241,173,99,226,
253,212,246,55,26,252,165,112,20,144,242,113,205,82,235,47,
3,254,38,59,254,54,59,181,83,142,90,251,137,2,140,90,
236,33,250,169,119,39,228,246,141,243,241,64,64,71,112,159,
222,71,56,23,204,227,154,163,227,188,124,182,237,35,223,213,
32,238,121,112,93,11,236,65,167,207,91,52,109,252,244,19,
87,18,126,47,199,254,191,173,113,159,72,255,84,120,95,248,
141,240,119,225,15,194,191,132,139,1,82,69,25,227,251,74,
163,126,168,57,152,231,87,178,127,36,60,147,93,147,239,40,
224,93,97,169,88,114,202,230,167,190,11,245,129,154,60,84,
0,64,108,163,217,235,165,224,207,167,218,253,148,88,198,68,
174,51,181,175,18,14,174,157,200,137,157,147,94,206,78,56,
20,31,60,206,71,230,75,94,183,99,62,173,249,93,138,131,
207,176,159,67,38,137,252,251,240,81,39,128,68,174,125,234,
231,117,49,22,27,137,156,251,228,247,138,69,127,111,209,126,
193,121,58,224,68,26,80,55,219,81,223,140,236,175,134,188,
20,231,74,78,71,242,140,129,126,175,135,181,116,2,57,172,
5,100,41,172,4,250,16,242,73,185,62,150,63,245,17,151,
147,78,78,184,224,68,166,242,197,250,31,130,143,90,0,203,
212,252,92,187,110,32,228,108,147,115,13,196,229,164,147,51,
214,111,42,95,90,191,169,124,177,126,173,92,228,48,182,94,
215,128,51,182,17,226,53,134,253,123,33,245,17,71,124,78,
46,229,100,46,223,95,24,203,239,30,63,31,224,191,11,222,
168,13,54,2,49,32,39,233,254,158,41,136,26,120,76,78,
211,79,92,78,58,57,227,254,78,229,75,247,119,42,223,165,
242,139,245,155,202,23,207,75,11,23,245,44,213,47,87,83,
251,120,30,224,108,156,10,235,1,216,248,232,27,21,205,185,
85,39,243,110,100,131,47,2,126,43,219,224,44,17,119,46,
188,41,164,178,146,131,61,233,134,14,214,83,3,124,212,38,
39,157,156,241,188,212,184,232,47,241,165,231,101,42,31,115,
1,164,133,171,150,95,39,158,220,122,61,15,117,2,196,164,
144,107,84,150,234,49,56,223,124,47,146,2,191,99,208,37,
121,162,206,107,193,28,87,178,127,33,156,10,216,246,163,105,
227,175,201,74,1,172,169,27,2,201,135,122,241,253,65,252,
206,3,159,191,247,24,66,179,170,147,23,62,120,145,169,124,
112,81,123,214,131,76,229,187,28,56,124,175,158,202,71,78,
228,118,136,252,188,78,184,176,145,67,228,247,138,233,213,191,
95,75,253,73,123,201,187,214,173,236,99,129,119,173,71,106,
255,83,122,87,217,106,0,231,237,72,58,2,31,125,62,91,
167,178,215,66,42,75,57,86,2,113,200,153,192,250,57,111,
241,57,201,124,196,148,164,87,103,39,28,138,15,30,231,36,
243,222,222,55,63,56,88,31,64,204,189,47,95,90,63,246,
147,156,115,160,158,53,233,20,192,88,246,4,153,202,151,214,
111,42,31,57,197,250,77,225,251,129,184,56,251,15,6,96,
255,76,216,10,87,170,21,123,98,48,39,123,85,147,75,5,
220,9,190,191,124,36,251,169,96,158,84,171,171,40,233,254,
146,3,185,164,60,173,249,245,26,219,9,236,11,50,149,47,
221,223,169,124,105,253,166,242,177,70,106,3,144,67,240,177,
102,215,15,78,174,171,120,109,165,253,196,52,137,120,182,10,
36,215,47,100,3,63,3,226,59,23,114,207,127,114,223,203,
74,22,243,119,131,39,61,39,110,115,190,249,109,106,77,122,
5,116,130,215,235,241,169,110,229,131,199,123,32,243,181,115,
108,222,86,62,56,226,254,122,124,170,91,249,58,241,145,35,
117,68,82,30,183,205,199,115,18,62,114,96,93,81,150,106,
228,192,62,18,255,153,198,25,180,241,167,241,114,189,38,196,
2,196,249,164,186,150,223,191,1,100,123,132,121,24,80,0,
0,};
